# FastRank website

My most frequently used learning-to-rank algorithms ported to rust for efficiency.

- [Develop on Github](https://github.com/jjfiv/fastrank)
- Visit on PyPI: [![PyPI version](https://badge.fury.io/py/fastrank.svg)](https://badge.fury.io/py/fastrank)

## Jupyter Notebook Example

There is an example notebook hosted via Google Colab that can run some examples: 

- [Tutorial Notebook](https://colab.research.google.com/drive/1IjF7yTin1XaNO_6mBNxAoQYTmF0nckk1)

